<?php

/**
 * @file
 * NodeExpireDateHelper class.
 */

namespace Drupal\node_expire_extras\Module\Expire;

use Drupal\node_expire\Module\Config\ConfigHandler;
use Drupal\node_expire_extras\Module\Config\NodeTypeConfigHandler;
use Drupal\node_expire_extras\Module\Config\UpdateExpireStartEnumInterface;
use Drupal\node_expire_extras\Module\Interval\IntervalStr;

/**
 * NodeExpireDateHelper class.
 *
 * Defines helper class for expire dates.
 */
class NodeExpireDateHelper {

  /**
   * Checks. whether the input parameter represents integer.
   */
  public static function isInteger($input) {
    return (ctype_digit(strval($input)));
  }

  /**
   * Extends expiry date for particular node type.
   */
  public static function extendExpireDate($node_type, $expire) {

    if (empty($expire)) {
      // Special case, date is not set, keep it.
      return '';
    }

    $config_handler = new NodeTypeConfigHandler($node_type);

    $start = REQUEST_TIME;

    // Period.
    switch ($config_handler->getUpdateExpiryStart()) {
      case UpdateExpireStartEnumInterface::EXPIRY_DATE:
        $start = strtotime($expire);
        break;

      case UpdateExpireStartEnumInterface::CURRENT_DATE:
        // Do nothing.
        break;

      default:
        // Current Date.
        // Do nothing.
        break;
    }

    $date_str = new IntervalStr($config_handler->getUpdateExpiryMultiplier(),
      $config_handler->getUpdateExpiryInterval());
    $str = $date_str->GetIntervalStr();

    $expire_date = date(ConfigHandler::getDateFormat(), strtotime($str, $start));

    return $expire_date;
  }

}
